@@ -1,12 +1,12 @@
-;;; scad-mode.el --- SCAD mode derived mode
+;;; scad-mode.el --- Major mode for editing SCAD files
 
 ;; Author:     Len Trigg
 ;; Maintainer: Len Trigg <lenbok@gmail.com>
 ;; Created:    March 2010
-;; Modified:   06 July 2012
+;; Modified:   24 May 2014
 ;; Keywords:   languages
 ;; URL:        https://raw.github.com/openscad/openscad/master/contrib/scad-mode.el
-;; Version:    90.0
+;; Version:    91.0
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -143,6 +143,7 @@
 (defvar scad-font-lock-keywords
   `(
     ("\\(module\\|function\\)[ \t]+\\(\\sw+\\)" (1 'font-lock-keyword-face nil) (2 'font-lock-function-name-face nil t))
+    ("\\(use\\|include\\)[ \t]*<\\([^>]+\\)>" (1 'font-lock-preprocessor-face nil) (2 'font-lock-type-face nil t))
     ("<\\(\\sw+\\)>" (1 'font-lock-builtin-face nil))
     ("$\\(\\sw+\\)" (1 'font-lock-builtin-face nil))
     (,scad-keywords-regexp . font-lock-keyword-face)
@@ -173,14 +174,24 @@
   )
 
 
+;; From: http://stackoverflow.com/questions/14520073/add-words-for-dynamic-expansion-to-emacs-mode
+(defun scad-prime-dabbrev ()
+  "Makes a hidden scad-mode buffer containing all the scad keywords, so dabbrev expansion just works."
+  (unless (get-buffer " *scad words*")
+    (with-current-buffer (get-buffer-create " *scad words*")
+      (scad-mode)
+      (insert "module function use include")  ; Explicitly add these -- they're not in the below vars
+      (insert (mapconcat 'identity (append scad-keywords scad-functions scad-modules) " ")))))
+(add-hook 'scad-mode-hook 'scad-prime-dabbrev)
+
+
 ;;; Indentation, based on http://www.emacswiki.org/emacs/download/actionscript-mode-haas-7.0.el
 
 (defun scad-indent-line ()
   "Indent current line of SCAD code."
   (interactive)
   (let ((savep (> (current-column) (current-indentation)))
-        (indent (condition-case nil (max (scad-calculate-indentation) 0)
-                  (error 0))))
+        (indent (max (scad-calculate-indentation) 0)))
     (if savep
         (save-excursion (indent-line-to indent))
       (indent-line-to indent))))
@@ -224,9 +235,9 @@
            ;; Don't count if in string or comment.
            ((scad-face-at-point (- (point) 1)))
            ((looking-back "\\s)")
-            (incf close-count))
+            (setq close-count (+ close-count 1)))
            ((looking-back "\\s(")
-            (incf open-count))
+            (setq open-count (+ open-count 1)))
            )))
       (- open-count close-count))))
 
