@@ -1,5 +1,4 @@
-#ifndef GLVIEW_H_
-#define GLVIEW_H_
+#pragma once
 
 /* GLView: A basic OpenGL rectangle for rendering images.
 
@@ -7,6 +6,7 @@ This class is inherited by:
 
 *QGLview - for Qt GUI
 *OffscreenView - for offscreen rendering, in tests and from command-line
+(This class is also overridden by NULLGL.cc for special experiments)
 
 The view assumes either a Gimbal Camera (rotation,translation,distance)
 or Vector Camera (eye,center/target) is being used. See Camera.h. The
@@ -25,48 +25,44 @@ Some actions (showCrossHairs) only work properly on Gimbal Camera.
 #endif
 #include "system-gl.h"
 #include <iostream>
-#include "renderer.h"
 #include "Camera.h"
+#include "colormap.h"
 
 class GLView
 {
 public:
 	GLView();
-	void setRenderer(Renderer* r);
+	void setRenderer(class Renderer* r);
+	Renderer *getRenderer() const { return this->renderer; }
 
 	void initializeGL();
 	void resizeGL(int w, int h);
 	virtual void paintGL();
 
-	void setCamera( Camera &cam );
+	void setCamera(const Camera &cam);
+	void setupCamera();
 
-	void setupGimbalCamPerspective();
-	void setupGimbalCamOrtho(double distance, bool offset=false);
-	void gimbalCamPaintGL();
-
-	void setupVectorCamPerspective();
-	void setupVectorCamOrtho(bool offset=false);
-	void vectorCamPaintGL();
-
-	void showCrosshairs();
-	void showAxes();
-	void showSmallaxes();
+	void setColorScheme(const ColorScheme &cs);
+	void setColorScheme(const std::string &cs);
+	void updateColorScheme();
 
 	virtual bool save(const char *filename) = 0;
 	virtual std::string getRendererInfo() const = 0;
 	virtual float getDPI() { return 1.0f; }
 
 	Renderer *renderer;
+	const ColorScheme *colorscheme;
 	Camera cam;
 	double far_far_away;
 	size_t width;
 	size_t height;
-	double w_h_ratio;
+	double aspectratio;
 	bool orthomode;
 	bool showaxes;
 	bool showfaces;
 	bool showedges;
 	bool showcrosshairs;
+	bool showscale;
 
 #ifdef ENABLE_OPENCSG
 	GLint shaderinfo[11];
@@ -77,6 +73,10 @@ public:
 	bool opencsg_support;
 	int opencsg_id;
 #endif
+private:
+	void showCrosshairs();
+	void showAxes(const Color4f &col);
+	void showSmallaxes(const Color4f &col);
+	void showScalemarkers(const Color4f &col);
+	void decodeMarkerValue(double i, double l, int size_div_sm);
 };
-
-#endif
