@@ -1,16 +1,18 @@
-#ifndef PROGRESSWIDGET_H_
-#define PROGRESSWIDGET_H_
+#pragma once
 
+#include "qtgettext.h"
 #include "ui_ProgressWidget.h"
+#include <QTime>
 
 class ProgressWidget : public QWidget, public Ui::ProgressWidget
 {
 	Q_OBJECT;
 	Q_PROPERTY(bool wasCanceled READ wasCanceled);
-
+	
 public:
 	ProgressWidget(QWidget *parent = NULL);
 	bool wasCanceled() const;
+	int elapsedTime() const;
 
 public slots:
 	void setRange(int minimum, int maximum);
@@ -23,6 +25,5 @@ signals:
 
 private:
 	bool wascanceled;
+	QTime starttime;
 };
-
-#endif
