@@ -1,5 +1,4 @@
-#ifndef THROWNTOGETHERRENDERER_H_
-#define THROWNTOGETHERRENDERER_H_
+#pragma once
 
 #include "renderer.h"
 
@@ -8,7 +7,8 @@ class ThrownTogetherRenderer : public Renderer
 public:
 	ThrownTogetherRenderer(class CSGChain *root_chain,
 												 CSGChain *highlights_chain, CSGChain *background_chain);
-	void draw(bool showfaces, bool showedges) const;
+	virtual void draw(bool showfaces, bool showedges) const;
+	virtual BoundingBox getBoundingBox() const;
 private:
 	void renderCSGChain(CSGChain *chain, bool highlight, bool background, bool showedges, 
 											bool fberror) const;
@@ -17,5 +17,3 @@ private:
 	CSGChain *highlights_chain;
 	CSGChain *background_chain;
 };
-
-#endif
