@@ -1,5 +1,4 @@
-#ifndef BOOST_UTILS_H_
-#define BOOST_UTILS_H_
+#pragma once
 
 #include <boost/filesystem.hpp>
 namespace fs = boost::filesystem;
@@ -9,5 +8,3 @@ namespace fs = boost::filesystem;
 fs::path boostfs_relative_path(const fs::path &path, const fs::path &relative_to);
 fs::path boostfs_normalize(const fs::path &path);
 fs::path boostfs_uncomplete(fs::path const p, fs::path const base);
-
-#endif
