@@ -42,8 +42,7 @@
 **
 ****************************************************************************/
 
-#ifndef CACHE_H
-#define CACHE_H
+#pragma once
 
 #include <boost/unordered_map.hpp>
 #include <boost/format.hpp>
@@ -178,11 +177,8 @@ void Cache<Key,T>::trim(int m)
 		Node *u = n;
 		n = n->p;
 #ifdef DEBUG
-		PRINTB("Trimming cache: %1% (%2% bytes)", *u->keyPtr % u->c);
+		PRINTB("Trimming cache: %1% (%2% bytes)", u->keyPtr->substr(0, 40) % u->c);
 #endif
 		unlink(*u);
 	}
 }
-
-#endif
-
