@@ -1,27 +1,28 @@
 #include "handle_dep.h"
 #include <string>
 #include <sstream>
-#include <QString>
-#include <QDir>
-#include <QSet>
 #include <stdlib.h> // for system()
 #include <boost/unordered_set.hpp>
 #include <boost/foreach.hpp>
+#include <boost/regex.hpp>
+#include <boost/filesystem.hpp>
+namespace fs = boost::filesystem;
+#include "boosty.h"
 
 boost::unordered_set<std::string> dependencies;
 const char *make_command = NULL;
 
 void handle_dep(const std::string &filename)
 {
-	if (filename[0] == '/')
-		dependencies.insert(filename);
-	else {
-		QString dep = QDir::currentPath() + QString("/") + QString::fromStdString(filename);
-		dependencies.insert(dep.toStdString());
-	}
-	if (!QFile(QString::fromStdString(filename)).exists() && make_command) {
+	fs::path filepath(filename);
+	std::string dep;
+	if (boosty::is_absolute(filepath)) dep = filename;
+	else dep = (fs::current_path() / filepath).string();
+	dependencies.insert(boost::regex_replace(filename, boost::regex("\\ "), "\\\\ "));
+
+	if (!fs::exists(filepath) && make_command) {
 		std::stringstream buf;
-		buf << make_command << " '" << QString::fromStdString(filename).replace("'", "'\\''").toUtf8().data() << "'";
+		buf << make_command << " '" << boost::regex_replace(filename, boost::regex("'"), "'\\''") << "'";
 		system(buf.str().c_str()); // FIXME: Handle error
 	}
 }
