@@ -1,5 +1,4 @@
-#ifndef LINEAREXTRUDENODE_H_
-#define LINEAREXTRUDENODE_H_
+#pragma once
 
 #include "node.h"
 #include "visitor.h"
@@ -11,7 +10,8 @@ public:
 	LinearExtrudeNode(const ModuleInstantiation *mi) : AbstractPolyNode(mi) {
 		convexity = slices = 0;
 		fn = fs = fa = height = twist = 0;
-		origin_x = origin_y = scale = 0;
+		origin_x = origin_y = 0;
+		scale_x = scale_y = 1;
 		center = has_twist = false;
 	}
   virtual Response accept(class State &state, Visitor &visitor) const {
@@ -22,11 +22,8 @@ public:
 
 	int convexity, slices;
 	double fn, fs, fa, height, twist;
-	double origin_x, origin_y, scale;
+	double origin_x, origin_y, scale_x, scale_y;
 	bool center, has_twist;
 	Filename filename;
 	std::string layername;
-	virtual PolySet *evaluate_polyset(class PolySetEvaluator *) const;
 };
-
-#endif
