@@ -1,5 +1,4 @@
-#ifndef LOCALSCOPE_H_
-#define LOCALSCOPE_H_
+#pragma once
 
 #include "typedefs.h"
 #include <boost/unordered_map.hpp>
@@ -12,15 +11,14 @@ public:
 
 	size_t numElements() const { return assignments.size() + children.size(); }
 	std::string dump(const std::string &indent) const;
-	std::vector<class AbstractNode*> instantiateChildren(const class Context *evalctx, class FileContext *filectx = NULL) const;
+	std::vector<class AbstractNode*> instantiateChildren(const class Context *evalctx) const;
 	void addChild(ModuleInstantiation *ch);
+	void apply(Context &ctx) const;
 
 	AssignmentList assignments;
-  ModuleInstantiationList children;
+	ModuleInstantiationList children;
 	typedef boost::unordered_map<std::string, class AbstractFunction*> FunctionContainer;
 	FunctionContainer functions;
 	typedef boost::unordered_map<std::string, class AbstractModule*> AbstractModuleContainer;
 	AbstractModuleContainer	modules;
 };
-
-#endif
