@@ -23,8 +23,7 @@ freely, subject to the following restrictions:
     distribution.
 */
 
-#ifndef LODEPNG_H
-#define LODEPNG_H
+#pragma once
 
 #include <string.h> /*for size_t*/
 
@@ -878,8 +877,6 @@ TODO:
 [ ] let the C++ wrapper catch exceptions coming from the standard library and return LodePNG error codes
 */
 
-#endif /*LODEPNG_H inclusion guard*/
-
 /*
 LodePNG Documentation
 ---------------------
