@@ -1,10 +1,10 @@
-#ifndef MATHC99_H_
-#define MATHC99_H_
+#pragma once
 
 #ifdef WIN32
 
 #include <cmath>
 //for native win32 builds we need to provide C99 math functions by ourselves
+double trunc(double a);
 double round(double a);
 float fmin(float a, float b);
 float fmax(float a, float b);
@@ -14,5 +14,3 @@ float fmax(float a, float b);
 #include <math.h>
 
 #endif
-
-#endif
