@@ -24,8 +24,7 @@
  *
  */
 
-#ifndef OPENSCAD_H
-#define OPENSCAD_H
+#pragma once
 
 extern class FileModule *parse(const char *text, const char *path, int debug);
 
@@ -36,5 +35,12 @@ extern std::string commandline_commands;
 // doing this, use currentdir to get the original CWD.
 extern std::string currentdir;
 
-#endif
-
+// Version number without any patch level indicator
+extern std::string openscad_shortversionnumber;
+// The full version number, e.g. 2014.03, 2015.03-1, 2014.12.23
+extern std::string openscad_versionnumber;
+// Version used for display, typically without patchlevel indicator,
+// but may include git commit id for snapshot builds
+extern std::string openscad_displayversionnumber;
+// Version used for detailed display
+extern std::string openscad_detailedversionnumber;
