@@ -1,5 +1,4 @@
-#ifndef PROJECTIONNODE_H_
-#define PROJECTIONNODE_H_
+#pragma once
 
 #include "node.h"
 #include "visitor.h"
@@ -19,7 +18,4 @@ public:
 
 	int convexity;
 	bool cut_mode;
-	virtual PolySet *evaluate_polyset(class PolySetEvaluator *evaluator) const;
 };
-
-#endif
