@@ -1,5 +1,4 @@
-#ifndef STATE_H_
-#define STATE_H_
+#pragma once
 
 #include <cstring>
 #include "linalg.h"
@@ -8,7 +7,7 @@ class State
 {
 public:
   State(const class AbstractNode *parent) 
-    : parentnode(parent), isprefix(false), ispostfix(false), numchildren(0) {
+    : parentnode(parent), isprefix(false), ispostfix(false), numchildren(0), prefernef(false) {
 		this->matrix_ = Transform3d::Identity();
 		this->color_.fill(-1.0f);
 	}
@@ -20,6 +19,8 @@ public:
   void setParent(const AbstractNode *parent) { this->parentnode = parent; }
 	void setMatrix(const Transform3d &m) { this->matrix_ = m; }
 	void setColor(const Color4f &c) { this->color_ = c; }
+	void setPreferNef(bool on) { this->prefernef = on; }
+	bool preferNef() const { return this->prefernef; }
 
   bool isPrefix() const { return this->isprefix; }
   bool isPostfix() const { return this->ispostfix; }
@@ -34,9 +35,8 @@ private:
   bool ispostfix;
   unsigned int numchildren;
 
+	bool prefernef;
 	// Transformation matrix and color. FIXME: Generalize such state variables?
 	Transform3d matrix_;
 	Color4f color_;
 };
-
-#endif
