@@ -26,9 +26,11 @@
 
 #include "transformnode.h"
 #include "module.h"
-#include "context.h"
+#include "evalcontext.h"
 #include "polyset.h"
 #include "builtin.h"
+#include "value.h"
+#include "printutils.h"
 #include <sstream>
 #include <vector>
 #include <assert.h>
@@ -48,83 +50,83 @@ class TransformModule : public AbstractModule
 public:
 	transform_type_e type;
 	TransformModule(transform_type_e type) : type(type) { }
-	virtual AbstractNode *evaluate(const Context *ctx, const ModuleInstantiation *inst) const;
+	virtual AbstractNode *instantiate(const Context *ctx, const ModuleInstantiation *inst, EvalContext *evalctx) const;
 };
 
-AbstractNode *TransformModule::evaluate(const Context *ctx, const ModuleInstantiation *inst) const
+AbstractNode *TransformModule::instantiate(const Context *ctx, const ModuleInstantiation *inst, EvalContext *evalctx) const
 {
 	TransformNode *node = new TransformNode(inst);
 
 	node->matrix = Transform3d::Identity();
 
-	std::vector<std::string> argnames;
-	std::vector<Expression*> argexpr;
+	AssignmentList args;
 
 	switch (this->type) {
 	case SCALE:
-		argnames += "v";
+		args += Assignment("v");
 		break;
 	case ROTATE:
-		argnames += "a", "v";
+		args += Assignment("a"), Assignment("v");
 		break;
 	case MIRROR:
-		argnames += "v";
+		args += Assignment("v");
 		break;
 	case TRANSLATE:
-		argnames += "v";
+		args += Assignment("v");
 		break;
 	case MULTMATRIX:
-		argnames += "m";
+		args += Assignment("m");
 		break;
 	default:
 		assert(false);
 	}
 
 	Context c(ctx);
-	c.args(argnames, argexpr, inst->argnames, inst->argvalues);
+	c.setVariables(args, evalctx);
+	inst->scope.apply(*evalctx);
 
 	if (this->type == SCALE)
 	{
 		Vector3d scalevec(1,1,1);
-		Value v = c.lookup_variable("v");
-		if (!v.getVec3(scalevec[0], scalevec[1], scalevec[2], 1.0)) {
+		ValuePtr v = c.lookup_variable("v");
+		if (!v->getVec3(scalevec[0], scalevec[1], scalevec[2], 1.0)) {
 			double num;
-			if (v.getDouble(num)) scalevec.setConstant(num);
+			if (v->getDouble(num)) scalevec.setConstant(num);
 		}
 		node->matrix.scale(scalevec);
 	}
 	else if (this->type == ROTATE)
 	{
-		Value val_a = c.lookup_variable("a");
-		if (val_a.type() == Value::VECTOR)
+		ValuePtr val_a = c.lookup_variable("a");
+		if (val_a->type() == Value::VECTOR)
 		{
 			Eigen::AngleAxisd rotx(0, Vector3d::UnitX());
 			Eigen::AngleAxisd roty(0, Vector3d::UnitY());
 			Eigen::AngleAxisd rotz(0, Vector3d::UnitZ());
 			double a;
-			if (val_a.toVector().size() > 0) {
-				val_a.toVector()[0].getDouble(a);
+			if (val_a->toVector().size() > 0) {
+				val_a->toVector()[0].getDouble(a);
 				rotx = Eigen::AngleAxisd(a*M_PI/180, Vector3d::UnitX());
 			}
-			if (val_a.toVector().size() > 1) {
-				val_a.toVector()[1].getDouble(a);
+			if (val_a->toVector().size() > 1) {
+				val_a->toVector()[1].getDouble(a);
 				roty = Eigen::AngleAxisd(a*M_PI/180, Vector3d::UnitY());
 			}
-			if (val_a.toVector().size() > 2) {
-				val_a.toVector()[2].getDouble(a);
+			if (val_a->toVector().size() > 2) {
+				val_a->toVector()[2].getDouble(a);
 				rotz = Eigen::AngleAxisd(a*M_PI/180, Vector3d::UnitZ());
 			}
 			node->matrix.rotate(rotz * roty * rotx);
 		}
 		else
 		{
-			Value val_v = c.lookup_variable("v");
+			ValuePtr val_v = c.lookup_variable("v");
 			double a = 0;
 
-			val_a.getDouble(a);
+			val_a->getDouble(a);
 
 			Vector3d axis(0,0,1);
-			if (val_v.getVec3(axis[0], axis[1], axis[2])) {
+			if (val_v->getVec3(axis[0], axis[1], axis[2])) {
 				if (axis.squaredNorm() > 0) axis.normalize();
 			}
 
@@ -135,10 +137,10 @@ AbstractNode *TransformModule::evaluate(const Context *ctx, const ModuleInstanti
 	}
 	else if (this->type == MIRROR)
 	{
-		Value val_v = c.lookup_variable("v");
+		ValuePtr val_v = c.lookup_variable("v");
 		double x = 1, y = 0, z = 0;
 	
-		if (val_v.getVec3(x, y, z)) {
+		if (val_v->getVec3(x, y, z)) {
 			if (x != 0.0 || y != 0.0 || z != 0.0) {
 				double sn = 1.0 / sqrt(x*x + y*y + z*z);
 				x *= sn, y *= sn, z *= sn;
@@ -157,25 +159,30 @@ AbstractNode *TransformModule::evaluate(const Context *ctx, const ModuleInstanti
 	}
 	else if (this->type == TRANSLATE)
 	{
-		Value v = c.lookup_variable("v");
+		ValuePtr v = c.lookup_variable("v");
 		Vector3d translatevec(0,0,0);
-		v.getVec3(translatevec[0], translatevec[1], translatevec[2]);
+		v->getVec3(translatevec[0], translatevec[1], translatevec[2]);
 		node->matrix.translate(translatevec);
 	}
 	else if (this->type == MULTMATRIX)
 	{
-		Value v = c.lookup_variable("m");
-		if (v.type() == Value::VECTOR) {
+		ValuePtr v = c.lookup_variable("m");
+		if (v->type() == Value::VECTOR) {
+			Matrix4d rawmatrix = Matrix4d::Identity();
 			for (int i = 0; i < 16; i++) {
 				size_t x = i / 4, y = i % 4;
-				if (y < v.toVector().size() && v.toVector()[y].type() == Value::VECTOR && x < v.toVector()[y].toVector().size())
-					v.toVector()[y].toVector()[x].getDouble(node->matrix(y, x));
+				if (y < v->toVector().size() && v->toVector()[y].type() == 
+						Value::VECTOR && x < v->toVector()[y].toVector().size())
+					v->toVector()[y].toVector()[x].getDouble(rawmatrix(y, x));
 			}
+			double w = rawmatrix(3,3);
+			if (w != 1.0) node->matrix = rawmatrix / w;
+			else node->matrix = rawmatrix;
 		}
 	}
 
-	std::vector<AbstractNode *> evaluatednodes = inst->evaluateChildren();
-	node->children.insert(node->children.end(), evaluatednodes.begin(), evaluatednodes.end());
+	std::vector<AbstractNode *> instantiatednodes = inst->instantiateChildren(evalctx);
+	node->children.insert(node->children.end(), instantiatednodes.begin(), instantiatednodes.end());
 
 	return node;
 }
@@ -188,8 +195,8 @@ std::string TransformNode::toString() const
 	for (int j=0;j<4;j++) {
 		stream << "[";
 		for (int i=0;i<4;i++) {
-			// FIXME: The 0 test is to avoid a leading minus before a single 0 (cosmetics)
-			stream << ((this->matrix(j, i)==0)?0:this->matrix(j, i));
+			Value v(this->matrix(j, i));
+			stream << v;
 			if (i != 3) stream << ", ";
 		}
 		stream << "]";
