@@ -1,5 +1,4 @@
-#ifndef VALUE_H_
-#define VALUE_H_
+#pragma once
 
 #include <vector>
 #include <string>
@@ -12,6 +11,7 @@
 #include <boost/lexical_cast.hpp>
 #endif
 #include <boost/cstdint.hpp>
+#include "memory.h"
 
 class QuotedString : public std::string
 {
@@ -82,12 +82,17 @@ public:
         this->end_val == other.end_val;
     }
 
+    double begin_value() { return begin_val; }
+    double step_value() { return step_val; }
+    double end_value() { return end_val; }
+
     iterator begin() { return iterator(*this, RANGE_TYPE_BEGIN); }
     iterator end() { return iterator(*this, RANGE_TYPE_END); }
 
     /// return number of steps, max uint32_t value if step is 0
     boost::uint32_t nbsteps() const;
     
+    friend class chr_visitor;
     friend class tostring_visitor;
     friend class bracket_visitor;
   };
@@ -116,12 +121,15 @@ public:
   ~Value() {}
 
   ValueType type() const;
+  bool isDefined() const;
+  bool isDefinedAs(const ValueType type) const;
   bool isUndefined() const;
 
   double toDouble() const;
   bool getDouble(double &v) const;
   bool toBool() const;
   std::string toString() const;
+  std::string chrString() const;
   const VectorType &toVector() const;
   bool getVec2(double &x, double &y) const;
   bool getVec3(double &x, double &y, double &z, double defaultval = 0.0) const;
@@ -137,7 +145,7 @@ public:
   bool operator>=(const Value &v) const;
   bool operator>(const Value &v) const;
   Value operator-() const;
-  Value operator[](const Value &v);
+  Value operator[](const Value &v) const;
   Value operator+(const Value &v) const;
   Value operator-(const Value &v) const;
   Value operator*(const Value &v) const;
@@ -160,4 +168,40 @@ private:
   Variant value;
 };
 
-#endif
+class ValuePtr : public shared_ptr<const Value>
+{
+public:
+  static ValuePtr undefined;
+
+	ValuePtr();
+	explicit ValuePtr(const Value &v);
+  ValuePtr(bool v);
+  ValuePtr(int v);
+  ValuePtr(double v);
+  ValuePtr(const std::string &v);
+  ValuePtr(const char *v);
+  ValuePtr(const char v);
+  ValuePtr(const Value::VectorType &v);
+  ValuePtr(const Value::RangeType &v);
+
+	operator bool() const { return **this; }
+
+  bool operator==(const ValuePtr &v) const;
+  bool operator!=(const ValuePtr &v) const;
+  bool operator<(const ValuePtr &v) const;
+  bool operator<=(const ValuePtr &v) const;
+  bool operator>=(const ValuePtr &v) const;
+  bool operator>(const ValuePtr &v) const;
+  ValuePtr operator-() const;
+  ValuePtr operator!() const;
+  ValuePtr operator[](const ValuePtr &v) const;
+  ValuePtr operator+(const ValuePtr &v) const;
+  ValuePtr operator-(const ValuePtr &v) const;
+  ValuePtr operator*(const ValuePtr &v) const;
+  ValuePtr operator/(const ValuePtr &v) const;
+  ValuePtr operator%(const ValuePtr &v) const;
+
+  const Value &operator*() const { return *this->get(); }
+
+private:
+};
